@@ -5,8 +5,8 @@ from .inference.base import BaseInference
 from .inference.mlflow import MLFlowInference
 from .loader.dataframe import DataFrameLoader
 from .loader.sql_table import SqlTableLoader
-from .models.word2vec import Word2Vec
-from .resources.io_manager import qdk_io_manager
+from .models.word2vec import Word2VecModel
+from .resources.io_manager import qdk_fs_io_manager, qdk_io_manager
 from .s3_connection import S3Connection
 from .training.base import BaseTrainer
 from .training.doc2vec import Doc2VecTrainer
