@@ -1,11 +1,12 @@
-from typing import Dict
+from typing import Dict, Union
 
+import dask.dataframe as dd
 import pandas as pd
-from dagster import Any, InputDefinition, Output, OutputDefinition
+from dagster import Any, InputDefinition, OutputDefinition
 from qdk.base import BaseComponent
 
 
-class InferenceComponent(BaseComponent):
+class BaseInference(BaseComponent):
     compute_function = "predict"
     tags = {
         "kind": "inference",
@@ -19,7 +20,11 @@ class InferenceComponent(BaseComponent):
     ]
 
     @classmethod
-    def predict(cls, data: Dict[str, pd.DataFrame], model: Any):
+    def predict(
+        cls,
+        df: Union[pd.DataFrame, dd.DataFrame],
+        model: Any,
+    ):
         raise NotImplementedError(
             'Make sure you added a "predict" function to the component'
         )
