@@ -4,12 +4,11 @@ from pandas import DataFrame
 class StoreDataFrame:
     df = DataFrame(
         {
-            "id": [1, 2, 3],
-            "name": ["John", "Jane", "Joe"],
+            "id": [1, 2],
+            "name": ["John", "Jane"],
             "description": [
-                "John loves writing pytests",
-                "Jane loves writing tests",
-                "Joe loves writing tests",
+                "John loves writing pytests in vscode",
+                "Dit is een Nederlandse tekst",
             ],
         }
     )
