@@ -11,7 +11,7 @@ from mlflow import autolog, set_experiment, sklearn, start_run, xgboost
 from sklearn.base import BaseEstimator
 
 
-class MLFlowTrainer(BaseTrainer):
+class MLFlowTrainingComponent(BaseTrainer):
     output_defs = [
         OutputDefinition(MLFlowRunType, "mlflow_run"),
     ]
